==> symbol-processing-aa-embeddable-2.1.0-1.0.29-sources.jar: org/jetbrains/kotlin/fir/analysis/checkers/CommonTypeCheckers.kt <==
/*
 * Copyright 2010-2021 JetBrains s.r.o. and Kotlin Programming Language contributors.
 * Use of this source code is governed by the Apache 2.0 license that can be found in the license/LICENSE.txt file.
 */

package ksp.org.jetbrains.kotlin.fir.analysis.checkers

import ksp.org.jetbrains.kotlin.fir.analysis.checkers.type.*

object CommonTypeCheckers : TypeCheckers() {
    override val typeRefCheckers: Set<FirTypeRefChecker> = setOf(
        FirSuspendModifierChecker,
    )

    override val resolvedTypeRefCheckers: Set<FirResolvedTypeRefChecker> = setOf(
        FirTypeAnnotationChecker,
        FirSuspendModifierChecker,
        FirDeprecatedTypeChecker,
        FirOptInUsageTypeRefChecker,
        FirStarProjectionModifierChecker,
        FirInOutProjectionModifierChecker,
        FirDuplicateParameterNameInFunctionTypeChecker,
        FirOptionalExpectationTypeChecker,
        FirIncompatibleClassTypeChecker,
        FirContextReceiversTypeChecker,
        FirContextReceiversDeprecatedTypeChecker,
        FirKotlinActualAnnotationHasNoEffectInKotlinTypeChecker,
        FirProjectionRelationChecker,
        FirArrayOfNothingTypeChecker,
    )

    override val intersectionTypeRefCheckers: Set<FirIntersectionTypeRefChecker> = setOf(
        FirDefinitelyNotNullableChecker,
    )

    override val functionTypeRefCheckers: Set<FirFunctionTypeRefChecker> = setOf(
        FirUnsupportedDefaultValueInFunctionTypeParameterChecker,
        FirUnsupportedModifiersInFunctionTypeParameterChecker,
    )
}

==> symbol-processing-aa-embeddable-2.3.0-sources.jar: org/jetbrains/kotlin/fir/analysis/checkers/CommonTypeCheckers.kt <==
/*
 * Copyright 2010-2021 JetBrains s.r.o. and Kotlin Programming Language contributors.
 * Use of this source code is governed by the Apache 2.0 license that can be found in the license/LICENSE.txt file.
 */

package ksp.org.jetbrains.kotlin.fir.analysis.checkers

import ksp.org.jetbrains.kotlin.fir.analysis.checkers.type.FirInlineExposedLessVisibleTypeChecker
import ksp.org.jetbrains.kotlin.fir.analysis.checkers.type.*

object CommonTypeCheckers : TypeCheckers() {
    override val typeRefCheckers: Set<FirTypeRefChecker> = setOf(
        FirSuspendModifierChecker,
    )

    override val resolvedTypeRefCheckers: Set<FirResolvedTypeRefChecker> = setOf(
        FirTypeAnnotationChecker,
        FirDeprecatedTypeChecker,
        FirOptInUsageTypeRefChecker,
        FirStarProjectionModifierChecker,
        FirInOutProjectionModifierChecker,
        FirDuplicateParameterNameInFunctionTypeChecker,
        FirOptionalExpectationTypeChecker,
        FirIncompatibleClassTypeChecker,
        FirContextualFunctionTypeChecker,
        FirKotlinActualAnnotationHasNoEffectInKotlinTypeChecker,
        FirProjectionRelationChecker,
        FirUpperBoundViolatedTypeChecker,
        FirArrayOfNothingTypeChecker,
        FirInlineExposedLessVisibleTypeChecker,
        RedundantNullableChecker,
        PlatformClassMappedToKotlinTypeRefChecker,
        FirMissingDependencyClassInTypeAliasTypeChecker,
    )

    override val intersectionTypeRefCheckers: Set<FirIntersectionTypeRefChecker> = setOf(
        FirDefinitelyNotNullableChecker,
    )

    override val functionTypeRefCheckers: Set<FirFunctionTypeRefChecker> = setOf(
        FirUnsupportedDefaultValueInFunctionTypeParameterChecker,
        FirUnsupportedModifiersInFunctionTypeParameterChecker,
        FirDslMarkerPropagationChecker,
    )
}
